@@ -169,6 +169,8 @@ namespace Breeze
         QRect progressBarLabelRect( const QStyleOption* option, const QWidget* ) const;
         QRect headerArrowRect( const QStyleOption* option, const QWidget* ) const;
         QRect headerLabelRect( const QStyleOption* option, const QWidget* ) const;
+        QRect tabBarTabLeftButtonRect( const QStyleOption*, const QWidget* ) const;
+        QRect tabBarTabRightButtonRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabBarRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabContentsRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabPaneRect( const QStyleOption*, const QWidget* ) const;
